ols(formula, data, contrasts,number.perms = 5000, quant, test = FALSE, all.quants = FALSE,weights)formula or a statement that can be coerced to this class.as.data.frame containing the variables and response in the model.
If missing the formula is evaluated in the environment from which the original function call was made.contrasts for further details.ols returns an object of class LADObj.
lad function call with the option OLS set equal to TRUE.
Kennedy, P.E., and B.S. Cade. 1996. Randomization tests for multiple regression. Communications in Statistics - Simulation and Computation 25, 923--936.
lad and hypothesis.test
Out <- ols(lcc~-1+apico+picopha,data = fraserf,number.perms = 10000)
summary(Out)Run the code above in your browser using DataLab